@@ -1,5 +1,5 @@
 /* html.c -- html-related utilities.
-   $Id: html.c,v 1.16 2004/03/10 23:28:43 dirt Exp $
+   $Id: html.c,v 1.18 2004/03/20 22:17:10 karl Exp $
 
    Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004 Free Software
    Foundation, Inc.
@@ -337,14 +337,17 @@ rel=\"generator-home\" title=\"Texinfo Homepage\">\n");
 char *
 escape_string (char *string)
 {
-  int i=0, newlen=0;
-  char * newstring;
+  char *newstring;
+  int i = 0, newlen = 0;
 
   do
     {
       /* Find how much to allocate. */
       switch (string[i])
         {
+        case '"':
+          newlen += 6;          /* `&quot;' */
+          break;
         case '&':
           newlen += 5;          /* `&amp;' */
           break;
@@ -366,6 +369,10 @@ escape_string (char *string)
     {
       switch (string[i])
         {
+        case '"':
+          strcpy (newstring, "&quot;");
+          newstring += 6;
+          break;
         case '&':
           strcpy (newstring, "&amp;");
           newstring += 5;
@@ -482,9 +489,9 @@ void
 #if defined (VA_FPRINTF) && __STDC__
 insert_html_tag_with_attribute (int start_or_end, char *tag, char *format, ...)
 #else
-insert_html_tag_with_attribute (elt, arg, format, va_alist)
-     int arg;
-     char *elt;
+insert_html_tag_with_attribute (start_or_end, tag, format, va_alist)
+     int start_or_end;
+     char *tag;
      char *format;
      va_dcl
 #endif
