@@ -1,5 +1,5 @@
 /* install-info -- create Info directory entry(ies) for an Info file.
-   $Id: install-info.c,v 1.3 2004/03/18 22:15:38 karl Exp $
+   $Id: install-info.c,v 1.4 2004/03/27 00:24:44 karl Exp $
 
    Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004 Free Software
    Foundation, Inc.
@@ -315,9 +315,28 @@ strip_info_suffix (char *fname)
 static int
 menu_item_equal (const char *item, char term_char, const char *name)
 {
+  const char *item_basename = item;
   unsigned name_len = strlen (name);
+
+  /* We must compare the basename in ITEM, since we are passed the
+     basename of the original info file.  Otherwise, a new entry like
+     "lilypond/lilypond" won't match "lilypond".
+     
+     Actually, it seems to me that we should really compare the whole
+     name, and not just the basename.  Couldn't there be dir1/foo.info
+     and dir2/foo.info?  Also, it seems like we should be using the
+     filename from the new dir entries, not the filename on the command
+     line.  Not worrying about those things right now, though.  --karl,
+     26mar04.  */
+  while (*item_basename && !IS_SLASH (*item_basename))
+    item_basename++;
+  if (! *item_basename)  
+    item_basename = item;  /* no /, use original */
+  else
+    item_basename++;       /* have /, move past it */
+    
   /* First, ITEM must actually match NAME (usually it won't).  */
-  int ret = strncasecmp (item, name, name_len) == 0;
+  int ret = strncasecmp (item_basename, name, name_len) == 0;
   if (ret)
     {
       /* Then, `foobar' doesn't match `foo', so be sure we've got all of
@@ -335,8 +354,8 @@ menu_item_equal (const char *item, char term_char, const char *name)
         {
           char *suffix = suffixes[i];
           unsigned suffix_len = strlen (suffix);
-          ret = strncasecmp (item + name_len, suffix, suffix_len) == 0
-                && item[name_len + suffix_len] == term_char;
+          ret = strncasecmp (item_basename + name_len, suffix, suffix_len) == 0
+                && item_basename[name_len + suffix_len] == term_char;
         }
     }
 
@@ -1114,8 +1133,8 @@ main (int argc, char **argv)
         case 'd':
           if (dirfile)
             {
-              fprintf (stderr, _("%s: Specify the Info directory only once.\n"),
-                       progname);
+              fprintf (stderr, _("%s: already have dir file: %s\n"),
+                       progname, dirfile);
               suggest_asking_for_help ();
             }
           dirfile = optarg;
@@ -1124,8 +1143,8 @@ main (int argc, char **argv)
         case 'D':
           if (dirfile)
             {
-              fprintf (stderr, _("%s: Specify the Info directory only once.\n"),
-                       progname);
+              fprintf (stderr, _("%s: already have dir file: %s\n"),
+                       progname, dirfile);
               suggest_asking_for_help ();
             }
           dirfile = concat (optarg, "", "/dir");
@@ -1295,7 +1314,6 @@ For more information about these matters, see the files named COPYING.\n"));
      Find the menu sections to add them in.
      In each section, find the proper alphabetical place to add
      each of the entries.  */
-
   if (!delete_flag)
     {
       struct node *node;
